[qet] qet/qet: [5629] Correction of some french and english notions and correction of typos.

[ Thread Index | Date Index | More lists.tuxfamily.org/qet Archives ]


Revision: 5629
Author:   nuri
Date:     2018-12-04 20:07:14 +0100 (Tue, 04 Dec 2018)
Log Message:
-----------
Correction of some french and english notions and correction of typos. Variable %machine changed in %plant.

Modified Paths:
--------------
    trunk/sources/SearchAndReplace/searchandreplaceworker.cpp
    trunk/sources/SearchAndReplace/ui/replacefoliowidget.cpp
    trunk/sources/SearchAndReplace/ui/replacefoliowidget.h
    trunk/sources/SearchAndReplace/ui/replacefoliowidget.ui
    trunk/sources/SearchAndReplace/ui/searchandreplacewidget.cpp
    trunk/sources/SearchAndReplace/ui/searchandreplacewidget.ui
    trunk/sources/autoNum/assignvariables.cpp
    trunk/sources/autoNum/numerotationcontext.cpp
    trunk/sources/autoNum/numerotationcontextcommands.cpp
    trunk/sources/autoNum/numerotationcontextcommands.h
    trunk/sources/autoNum/ui/numparteditorw.cpp
    trunk/sources/autoNum/ui/numparteditorw.h
    trunk/sources/bordertitleblock.cpp
    trunk/sources/bordertitleblock.h
    trunk/sources/diagramcontext.h
    trunk/sources/diagramfoliolist.cpp
    trunk/sources/editor/qetelementeditor.cpp
    trunk/sources/editor/ui/elementpropertieseditorwidget.cpp
    trunk/sources/elementtextpattern.cpp
    trunk/sources/nomenclature.cpp
    trunk/sources/qetapp.cpp
    trunk/sources/qetdiagrameditor.cpp
    trunk/sources/titleblock/templatecellwidget.cpp
    trunk/sources/titleblockproperties.cpp
    trunk/sources/titleblockproperties.h
    trunk/sources/ui/configpage/generalconfigurationpage.ui
    trunk/sources/ui/reportpropertiewidget.ui
    trunk/sources/ui/titleblockpropertieswidget.cpp
    trunk/sources/ui/titleblockpropertieswidget.ui

Modified: trunk/sources/SearchAndReplace/searchandreplaceworker.cpp
===================================================================
--- trunk/sources/SearchAndReplace/searchandreplaceworker.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/searchandreplaceworker.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -57,7 +57,7 @@
 	}
 	
 	QUndoStack *us = project->undoStack();
-	us->beginMacro(QObject::tr("Chercher remplacer les propriétés de folio"));
+    us->beginMacro(QObject::tr("Chercher/remplacer les propriétés de folio"));
 	for (Diagram *d : diagram_list)
 	{
 		TitleBlockProperties old_propertie = d->border_and_titleblock.exportTitleBlock();
@@ -87,12 +87,12 @@
 				new_properties.filename = m_titleblock_properties.filename;
 			}
 		}
-		if (!m_titleblock_properties.machine.isEmpty())
+        if (!m_titleblock_properties.plant.isEmpty())
 		{
-			if (m_titleblock_properties.machine == eraseText()) {
-				new_properties.machine.clear();
+            if (m_titleblock_properties.plant == eraseText()) {
+                new_properties.plant.clear();
 			} else {
-				new_properties.machine = m_titleblock_properties.machine;
+                new_properties.plant = m_titleblock_properties.plant;
 			}
 		}
 		if (!m_titleblock_properties.locmach.isEmpty())
@@ -168,7 +168,7 @@
 		}
 	}
 	
-	project_->undoStack()->beginMacro(QObject::tr("Chercher remplacer les propriétés d'éléments"));
+    project_->undoStack()->beginMacro(QObject::tr("Chercher/remplacer les propriétés d'éléments"));
 	for (Element *elmt : list)
 	{
 			//We apply change only for master, slave, and terminal element.
@@ -228,7 +228,7 @@
 		}
 	}
 	
-	project_->undoStack()->beginMacro(QObject::tr("Chercher remplacer des textes independant"));
+    project_->undoStack()->beginMacro(QObject::tr("Chercher/remplacer des textes independants"));
 	for (IndependentTextItem *text : list)
 	{
 		QString before = text->toPlainText();

Modified: trunk/sources/SearchAndReplace/ui/replacefoliowidget.cpp
===================================================================
--- trunk/sources/SearchAndReplace/ui/replacefoliowidget.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/ui/replacefoliowidget.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -46,7 +46,7 @@
 	prop.title    = ui->m_title_le ->text();
 	prop.author   = ui->m_author_le->text();
 	prop.filename = ui->m_file_le  ->text();
-	prop.machine  = ui->m_mach     ->text();
+    prop.plant  = ui->m_plant     ->text();
 	prop.locmach  = ui->m_loc      ->text();
 	prop.indexrev = ui->m_indice   ->text();
 	prop.folio    = ui->m_folio_le ->text();
@@ -78,7 +78,7 @@
 	ui->m_title_le ->setText (properties.title);
 	ui->m_author_le->setText (properties.author);
 	ui->m_file_le  ->setText (properties.filename);
-	ui->m_mach     ->setText (properties.machine);
+    ui->m_plant     ->setText (properties.plant);
 	ui->m_loc      ->setText (properties.locmach);
 	ui->m_indice   ->setText (properties.indexrev);
 	ui->m_folio_le ->setText (properties.folio);
@@ -162,9 +162,9 @@
 	ui->m_folio_le->setDisabled(ui->m_folio_cb->isChecked());
 }
 
-void ReplaceFolioWidget::on_m_mach_cb_clicked() {
-    ui->m_mach->setText(ui->m_mach_cb->isChecked() ? SearchAndReplaceWorker::eraseText() : QString());
-	ui->m_mach->setDisabled(ui->m_mach_cb->isChecked());
+void ReplaceFolioWidget::on_m_plant_cb_clicked() {
+    ui->m_plant->setText(ui->m_plant_cb->isChecked() ? SearchAndReplaceWorker::eraseText() : QString());
+    ui->m_plant->setDisabled(ui->m_plant_cb->isChecked());
 }
 
 void ReplaceFolioWidget::on_m_loc_cb_clicked() {

Modified: trunk/sources/SearchAndReplace/ui/replacefoliowidget.h
===================================================================
--- trunk/sources/SearchAndReplace/ui/replacefoliowidget.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/ui/replacefoliowidget.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -47,7 +47,7 @@
 		void on_m_author_cb_clicked();
 		void on_m_file_cb_clicked();
 		void on_m_folio_cb_clicked();
-		void on_m_mach_cb_clicked();
+        void on_m_plant_cb_clicked();
 		void on_m_loc_cb_clicked();
 		void on_m_indice_cb_clicked();
 		

Modified: trunk/sources/SearchAndReplace/ui/replacefoliowidget.ui
===================================================================
--- trunk/sources/SearchAndReplace/ui/replacefoliowidget.ui	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/ui/replacefoliowidget.ui	2018-12-04 19:07:14 UTC (rev 5629)
@@ -6,7 +6,7 @@
    <rect>
     <x>0</x>
     <y>0</y>
-    <width>710</width>
+    <width>744</width>
     <height>705</height>
    </rect>
   </property>
@@ -219,9 +219,9 @@
           </widget>
          </item>
          <item row="6" column="3">
-          <widget class="QLineEdit" name="m_mach">
+          <widget class="QLineEdit" name="m_plant">
            <property name="toolTip">
-            <string>Disponible en tant que %machine pour les modèles de cartouches</string>
+            <string>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Disponible en tant que %plant pour les modèles de cartouches&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</string>
            </property>
            <property name="placeholderText">
             <string>Ne pas modifier</string>
@@ -276,7 +276,7 @@
           </widget>
          </item>
          <item row="6" column="4">
-          <widget class="QCheckBox" name="m_mach_cb">
+          <widget class="QCheckBox" name="m_plant_cb">
            <property name="toolTip">
             <string>Supprimer ce texte</string>
            </property>

Modified: trunk/sources/SearchAndReplace/ui/searchandreplacewidget.cpp
===================================================================
--- trunk/sources/SearchAndReplace/ui/searchandreplacewidget.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/ui/searchandreplacewidget.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -659,7 +659,7 @@
 	list.append(prop.title);
 	list.append(prop.author);
 	list.append(prop.filename);
-	list.append(prop.machine);
+    list.append(prop.plant);
 	list.append(prop.locmach);
 	list.append(prop.indexrev);
 	list.append(prop.folio);

Modified: trunk/sources/SearchAndReplace/ui/searchandreplacewidget.ui
===================================================================
--- trunk/sources/SearchAndReplace/ui/searchandreplacewidget.ui	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/SearchAndReplace/ui/searchandreplacewidget.ui	2018-12-04 19:07:14 UTC (rev 5629)
@@ -169,6 +169,9 @@
        <property name="enabled">
         <bool>true</bool>
        </property>
+       <property name="toolTip">
+        <string>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Définir les propriétés à remplacer dans les éléments&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</string>
+       </property>
        <property name="text">
         <string>Élément</string>
        </property>
@@ -196,6 +199,9 @@
        <property name="enabled">
         <bool>false</bool>
        </property>
+       <property name="toolTip">
+        <string>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Définir les propriétés à remplacer dans les conducteurs&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</string>
+       </property>
        <property name="text">
         <string>Conducteur</string>
        </property>
@@ -210,6 +216,9 @@
      </item>
      <item row="1" column="4">
       <widget class="QPushButton" name="m_folio_pb">
+       <property name="toolTip">
+        <string>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Définir les propriétés à remplacer dans les folios&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</string>
+       </property>
        <property name="text">
         <string>Folio</string>
        </property>

Modified: trunk/sources/autoNum/assignvariables.cpp
===================================================================
--- trunk/sources/autoNum/assignvariables.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/assignvariables.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -178,13 +178,13 @@
 	{
 		QString str = formula;
 		str.replace("%{label}", dc.value("label").toString());
-		str.replace("%{group-function}", dc.value("group-function").toString());
+        str.replace("%{plant}", dc.value("plant").toString());
 		str.replace("%{comment}", dc.value("comment").toString());
 		str.replace("%{description}", dc.value("description").toString());
 		str.replace("%{designation}", dc.value("designation").toString());
 		str.replace("%{manufacturer}", dc.value("manufacturer").toString());
 		str.replace("%{manufacturer-reference}", dc.value("manufacturer-reference").toString());
-		str.replace("%{provider}", dc.value("provider").toString());
+        str.replace("%{supplier}", dc.value("supplier").toString());
 		str.replace("%{quantity}", dc.value("quantity").toString());
 		str.replace("%{unity}", dc.value("unity").toString());
 		str.replace("%{auxiliary1}", dc.value("auxiliary1").toString());
@@ -212,7 +212,7 @@
 			m_assigned_label.replace("%f",     QString::number(m_diagram->folioIndex()+1));
 			m_assigned_label.replace("%id",    QString::number(m_diagram->folioIndex()+1));
 			m_assigned_label.replace("%total", QString::number(m_diagram->border_and_titleblock.folioTotal()));
-			m_assigned_label.replace("%M",  m_diagram -> border_and_titleblock.machine());
+            m_assigned_label.replace("%M",  m_diagram -> border_and_titleblock.plant());
 			m_assigned_label.replace("%LM", m_diagram -> border_and_titleblock.locmach());
 
 	QSettings settings;
@@ -426,7 +426,7 @@
 			else if (type == "folio") {
 				formula.append("%F");
 			}
-			else if (type == "machine") {
+            else if (type == "plant") {
 				formula.append("%M");
 			}
 			else if (type == "locmach") {

Modified: trunk/sources/autoNum/numerotationcontext.cpp
===================================================================
--- trunk/sources/autoNum/numerotationcontext.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/numerotationcontext.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -101,7 +101,7 @@
  * @return all type use to numerotation
  */
 QString NumerotationContext::validRegExpNum () const {
-	return ("unit|unitfolio|ten|tenfolio|hundred|hundredfolio|string|idfolio|folio|machine|locmach|elementline|elementcolumn|elementprefix");
+    return ("unit|unitfolio|ten|tenfolio|hundred|hundredfolio|string|idfolio|folio|plant|locmach|elementline|elementcolumn|elementprefix");
 }
 
 /**

Modified: trunk/sources/autoNum/numerotationcontextcommands.cpp
===================================================================
--- trunk/sources/autoNum/numerotationcontextcommands.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/numerotationcontextcommands.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -124,8 +124,8 @@
 		strategy_ = new FolioNum (diagram_);
 		return;
 	}
-	else if (str=="machine"){
-		strategy_ = new MachineNum (diagram_);
+    else if (str=="plant"){
+        strategy_ = new PlantNum (diagram_);
 		return;
 	}
 	else if (str=="locmach"){
@@ -499,32 +499,32 @@
 /**
  * Constructor
  */
-MachineNum::MachineNum (Diagram *d):
+PlantNum::PlantNum (Diagram *d):
 	NumStrategy (d)
 {}
 
 /**
- * @brief MachineNum::toRepresentedString
+ * @brief PlantNum::toRepresentedString
  * @return the represented string of folio
  */
-QString MachineNum::toRepresentedString(const QString str) const {
+QString PlantNum::toRepresentedString(const QString str) const {
 	Q_UNUSED(str);
 	return "%M";
 }
 
 /**
- * @brief MachineNum::next
+ * @brief PlantNum::next
  * @return the next NumerotationContext nc at position i
  */
-NumerotationContext MachineNum::next (const NumerotationContext &nc, const int i) const {
+NumerotationContext PlantNum::next (const NumerotationContext &nc, const int i) const {
 	return (nextString(nc, i));
 }
 
 /**
- * @brief MachineNum::previous
+ * @brief PlantNum::previous
  * @return the previous NumerotationContext nc at posiiton i
  */
-NumerotationContext MachineNum::previous(const NumerotationContext &nc, const int i) const {
+NumerotationContext PlantNum::previous(const NumerotationContext &nc, const int i) const {
 	return (nextString(nc, i));
 }
 

Modified: trunk/sources/autoNum/numerotationcontextcommands.h
===================================================================
--- trunk/sources/autoNum/numerotationcontextcommands.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/numerotationcontextcommands.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -141,10 +141,10 @@
 	NumerotationContext previous (const NumerotationContext &, const int) const override;
 };
 
-class MachineNum: public NumStrategy
+class PlantNum: public NumStrategy
 {
 	public:
-	MachineNum (Diagram *);
+    PlantNum (Diagram *);
 	QString toRepresentedString(const QString) const override;
 	NumerotationContext next     (const NumerotationContext &, const int) const override;
 	NumerotationContext previous (const NumerotationContext &, const int) const override;

Modified: trunk/sources/autoNum/ui/numparteditorw.cpp
===================================================================
--- trunk/sources/autoNum/ui/numparteditorw.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/ui/numparteditorw.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -58,7 +58,7 @@
 		else if (strl.at(0)=="string") setType(NumPartEditorW::string);
 		else if (strl.at(0)=="idfolio") setType(NumPartEditorW::idfolio);
 		else if (strl.at(0)=="folio") setType(NumPartEditorW::folio);
-		else if (strl.at(0)=="machine") setType(NumPartEditorW::machine);
+        else if (strl.at(0)=="plant") setType(NumPartEditorW::plant);
 		else if (strl.at(0)=="locmach") setType(NumPartEditorW::locmach);
 		else if (strl.at(0)=="elementline") setType(NumPartEditorW::elementline);
 		else if (strl.at(0)=="elementcolumn") setType(NumPartEditorW::elementcolumn);
@@ -91,12 +91,12 @@
 	{
 		items	<< tr("Chiffre 1") << tr("Chiffre 1 - Folio") << tr("Chiffre 01")
 				<< tr("Chiffre 01 - Folio") << tr("Chiffre 001") << tr("Chiffre 001 - Folio")
-				<< tr("Texte") << tr("N° folio") << tr("Folio") << tr("Machine") << tr("Locmach");
+                << tr("Texte") << tr("N° folio") << tr("Folio") << tr("Installation") << tr("Locmach");
 	}
 	else
 		items << tr("Chiffre 1") << tr("Chiffre 1 - Folio") << tr("Chiffre 01")
 			  << tr("Chiffre 01 - Folio") << tr("Chiffre 001") << tr("Chiffre 001 - Folio")
-			  << tr("Texte") << tr("N° folio") << tr("Folio") << tr("Machine") << tr("Locmach")
+              << tr("Texte") << tr("N° folio") << tr("Folio") << tr("Installation") << tr("Locmach")
 			  << tr("Element Line") << tr("Element Column") << tr("Element Prefix");
 	ui->type_cb->insertItems(0,items);
 }
@@ -136,8 +136,8 @@
 		case folio:
 			type_str = "folio";
 			break;
-		case machine:
-			type_str = "machine";
+        case plant:
+            type_str = "plant";
 			break;
 		case locmach:
 			type_str = "locmach";
@@ -164,7 +164,7 @@
  * @return true if value field isn't empty or if type is folio
  */
 bool NumPartEditorW::isValid() {
-	if (type_ == folio || type_ == idfolio || type_ == elementline || type_ == machine || type_ == locmach ||
+    if (type_ == folio || type_ == idfolio || type_ == elementline || type_ == plant || type_ == locmach ||
 		type_ == elementcolumn || type_ == elementprefix) {return true;}
 	else if(ui -> value_field -> text().isEmpty()) {return false;}
 	else return true;
@@ -193,8 +193,8 @@
 		setType(idfolio);
 	else if (ui->type_cb->currentText() == tr("Folio"))
 		setType(folio);
-	else if (ui->type_cb->currentText() == tr("Machine"))
-		setType(machine);
+    else if (ui->type_cb->currentText() == tr("Installation"))
+        setType(plant);
 	else if (ui->type_cb->currentText() == tr("Locmach"))
 		setType(locmach);
 	else if (ui->type_cb->currentText() == tr("Element Line"))
@@ -234,7 +234,7 @@
 	//if @t is a numeric type and preview type @type_ isn't a numeric type
 	//or @fnum is true, we set numeric behavior
 	if ( ((t==unit || t==unitfolio || t==ten || t==tenfolio || t==hundred || t==hundredfolio) &&
-		  (type_==string || type_==folio || type_==machine || type_==locmach ||type_==idfolio ||
+          (type_==string || type_==folio || type_==plant || type_==locmach ||type_==idfolio ||
 		   type_==elementcolumn || type_==elementline || type_==elementprefix))
 		 || fnum) {
 		ui -> value_field -> clear();
@@ -244,7 +244,7 @@
 		ui -> increase_spinBox -> setValue(1);
 	}
 	//@t isn't a numeric type
-	else if (t == string || t == folio || t == idfolio || t == elementline || t == machine || t == locmach ||
+    else if (t == string || t == folio || t == idfolio || t == elementline || t == plant || t == locmach ||
 			 t == elementcolumn || t == elementprefix) {
 		ui -> value_field -> clear();
 		ui -> increase_spinBox -> setDisabled(true);
@@ -256,7 +256,7 @@
 			ui -> value_field -> setDisabled(true);
 			ui -> increase_spinBox -> setDisabled(true);
 		}
-		else if (t==machine) {
+        else if (t==plant) {
 			ui -> value_field -> setDisabled(true);
 			ui -> increase_spinBox -> setDisabled(true);
 		}
@@ -309,8 +309,8 @@
 		i = ui->type_cb->findText(tr("N° folio"));
 	else if (t == folio)
 		i = ui->type_cb->findText(tr("Folio"));
-	else if (t == machine)
-		i = ui->type_cb->findText(tr("Machine"));
+    else if (t == plant)
+        i = ui->type_cb->findText(tr("Installation"));
 	else if (t == locmach)
 		i = ui->type_cb->findText(tr("Locmach"));
 	else if (t == elementline)

Modified: trunk/sources/autoNum/ui/numparteditorw.h
===================================================================
--- trunk/sources/autoNum/ui/numparteditorw.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/autoNum/ui/numparteditorw.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -42,7 +42,7 @@
 		~NumPartEditorW() override;
 
 		enum type {unit,unitfolio,ten,tenfolio, hundred, hundredfolio,
-				   string,idfolio,folio,machine,locmach,
+                   string,idfolio,folio,plant,locmach,
 				   elementline,elementcolumn,elementprefix,
 				  };
 		NumerotationContext toNumContext();

Modified: trunk/sources/bordertitleblock.cpp
===================================================================
--- trunk/sources/bordertitleblock.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/bordertitleblock.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -241,7 +241,7 @@
 	ip.date = date();
 	ip.title = title();
 	ip.filename = fileName();
-	ip.machine = machine();
+    ip.plant = plant();
 	ip.locmach = locmach();
 	ip.indexrev = indexrev();
 	ip.version = version();
@@ -264,7 +264,7 @@
 	setDate(ip.date);
 	setTitle(ip.title);
 	setFileName(ip.filename);
-	setMachine(ip.machine);
+    setPlant(ip.plant);
 	setLocMach(ip.locmach);
 	setIndicerev(ip.indexrev);
 	setVersion(QET::displayedVersion);
@@ -715,7 +715,7 @@
 	context.addValue("date",        btb_date_.toString(Qt::SystemLocaleShortDate));
 	context.addValue("title",       btb_title_);
 	context.addValue("filename",    btb_filename_);
-	context.addValue("machine",     btb_machine_);
+    context.addValue("plant",     btb_plant_);
 	context.addValue("locmach",     btb_locmach_);
 	context.addValue("indexrev",    btb_indexrev_);
 	context.addValue("version",     btb_version_);

Modified: trunk/sources/bordertitleblock.h
===================================================================
--- trunk/sources/diagramcontext.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/diagramcontext.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -35,7 +35,7 @@
  * formula                        -> formula used to create the label (formula is make with variable)
  * designation                    -> exhaustive comment used to explain what the element does.
  * description                    -> exhaustive description used to explain what the element does.
- * group-function                  -> the group function of element
+ * plant                          -> the plant assigned to the element
  * comment                        -> a little comment wich can be displayed in the folio
  * manufacturer                   -> the manufacturer of the element
  * manufacturer-reference         -> the manufacturer reference of the element
@@ -43,10 +43,10 @@
  * unity                          -> unity of the element
  * auxiliary1                     -> auxiliary 1 of element
  * auxiliary2                     -> auxiliary 2 of element
- * machine-manufacturer-reference -> reference of the manufacturer machine
- * provider                       -> the provider of the element
+ * machine-manufacturer-reference -> reference of the machine manufacturer
+ * supplier                       -> the supplier of the element
  * function                       -> the function of element
- * location                       -> the location of the element
+ * location                       -> the location assigned to the element
  * frozenLabel                    -> label locked at a given time
  *
  */

Modified: trunk/sources/diagramfoliolist.cpp
===================================================================
--- trunk/sources/diagramfoliolist.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/diagramfoliolist.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -93,7 +93,7 @@
 		fillRow(p, row_rect, diagram_list[i] -> border_and_titleblock.author(),
 				diagram_list[i] -> title(),
 				diagram_list[i] -> border_and_titleblock.finalfolio(),
-				diagram_list[i] -> border_and_titleblock.machine(),
+                diagram_list[i] -> border_and_titleblock.plant(),
 				diagram_list[i] -> border_and_titleblock.locmach(),
 				diagram_list[i] -> border_and_titleblock.indexrev(),
 				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
@@ -101,7 +101,7 @@
 			fillRow(p, row_rect, diagram_list[i] -> border_and_titleblock.author(),
 				diagram_list[i] -> title(),
 				QString::number(diagram_list[i] ->folioIndex()+1),
-				diagram_list[i] -> border_and_titleblock.machine(),
+                diagram_list[i] -> border_and_titleblock.plant(),
 				diagram_list[i] -> border_and_titleblock.locmach(),
 				diagram_list[i] -> border_and_titleblock.indexrev(),
 				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
@@ -120,7 +120,7 @@
  * @param row_rect rectangle where we must draw the new row
  */
 void DiagramFolioList::fillRow(QPainter *qp, const QRectF &row_rect, const QString& author, const QString& title,
-							   const QString& folio, const QString& machine, const QString& loc, const QString& indexrev, const QString& date)
+                               const QString& folio, const QString& plant, const QString& loc, const QString& indexrev, const QString& date)
 {
 	qreal x = row_rect.topLeft().x();
 	qreal y = row_rect.topLeft().y();
@@ -166,12 +166,12 @@
 	x += colWidths[1]*row_rect.width();
 	
 	
-	if (origFontMetrics.width(machine) > 0.95*colWidths[2]*row_rect.width())
-		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[2]*row_rect.width() / origFontMetrics.width(machine));
+    if (origFontMetrics.width(plant) > 0.95*colWidths[2]*row_rect.width())
+        workingFont.setPointSizeF(origFontSize * 0.95*colWidths[2]*row_rect.width() / origFontMetrics.width(plant));
 	else
 		workingFont.setPointSizeF(origFontSize);
 	qp -> setFont(workingFont);
-	qp -> drawText(QRectF(x, y, colWidths[3]*row_rect.width(), row_rect.height()), Qt::AlignCenter, machine);
+    qp -> drawText(QRectF(x, y, colWidths[3]*row_rect.width(), row_rect.height()), Qt::AlignCenter, plant);
 	x += colWidths[2]*row_rect.width();
 	
 	
@@ -264,7 +264,7 @@
 	QString authorTranslatable(QObject::tr("Auteur"));
 	QString titleTranslatable(QObject::tr("Titre"));
 	QString folioTranslatable(QObject::tr("Folio"));
-	QString machineTranslatable(QObject::tr("Installation"));
+    QString plantTranslatable(QObject::tr("Installation"));
 	QString locTranslatable(QObject::tr("Localisation"));
 	QString indexrevTranslatable(QObject::tr("Rev"));
 	QString dateTranslatable(QObject::tr("Date"));
@@ -271,6 +271,6 @@
 
 	qp->save();
 	qp->setFont(QETApp::diagramTextsFont(13));
-	fillRow(qp, row_RectF, authorTranslatable, titleTranslatable, folioTranslatable, machineTranslatable, locTranslatable, indexrevTranslatable, dateTranslatable);
+    fillRow(qp, row_RectF, authorTranslatable, titleTranslatable, folioTranslatable, plantTranslatable, locTranslatable, indexrevTranslatable, dateTranslatable);
 	qp->restore();
 }

Modified: trunk/sources/editor/qetelementeditor.cpp
===================================================================
--- trunk/sources/editor/qetelementeditor.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/editor/qetelementeditor.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -741,7 +741,7 @@
 		if (errors.size())
 			dialog_message += QString (tr(" et"));
 
-		dialog_message += QString (tr(" %n avertissment(s)", "warnings", warnings.size()));
+        dialog_message += QString (tr(" %n avertissement(s)", "warnings", warnings.size()));
 	}
 	dialog_message += " :";
 

Modified: trunk/sources/editor/ui/elementpropertieseditorwidget.cpp
===================================================================
--- trunk/sources/editor/ui/elementpropertieseditorwidget.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/editor/ui/elementpropertieseditorwidget.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -152,7 +152,7 @@
  */
 void ElementPropertiesEditorWidget::populateTree()
 {
-	QStringList keys{"label", "group-function", "comment", "description", "designation", "manufacturer", "manufacturer-reference", "provider", "quantity", "unity", "machine-manufacturer-reference"};
+    QStringList keys{"label", "plant", "comment", "description", "designation", "manufacturer", "manufacturer-reference", "supplier", "quantity", "unity", "machine-manufacturer-reference"};
 	
 	for(const QString& key : keys)
 	{

Modified: trunk/sources/elementtextpattern.cpp
===================================================================
--- trunk/sources/elementtextpattern.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/elementtextpattern.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -62,7 +62,7 @@
 	{
 		bool r = QMessageBox::question(parentWidget(),
 									   QObject::tr("Configuration de textes"),
-									   QObject::tr("Une configuration de textes nommé << %1 >> existe déjà.\n"
+                                       QObject::tr("Une configuration de textes nommée << %1 >> existe déjà.\n"
 												   "Voulez-vous la remplacer ?").arg(m_name));
 		
 		if(r == false)

Modified: trunk/sources/nomenclature.cpp
===================================================================
--- trunk/sources/nomenclature.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/nomenclature.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -60,7 +60,7 @@
 			if(!QFile::remove ( filename ) ){
 				QMessageBox::critical(this->m_parent, QObject::tr("Erreur"),
 									  QObject::tr("Impossible de remplacer le fichier!\n\n")+
-									  "Destination: "+filename+"\n");
+                                      "Destination : "+filename+"\n");
 				return false;
 			}	
 		}
@@ -84,9 +84,9 @@
 {
 	//Process...
 	QString data = QObject::tr("NOMENCLATURE : ") + m_project -> title() + "\n\n";
-    data += QObject::tr("A001") +";"  //:Don't translate this text!    //ID for folio number
+    data += QObject::tr("A001") +";"  //:Don't translate this text!    //ID for folio position in project
     ""+ QObject::tr("B001") +";"      //:Don't translate this text!    //ID for folio title
-    ""+ QObject::tr("C001") +";"      //:Don't translate this text!    //ID for folio label
+    ""+ QObject::tr("C001") +";"      //:Don't translate this text!    //ID for folio number
     ""+ QObject::tr("D001") +";"      //:Don't translate this text!    //ID for qet designation
     ""+ QObject::tr("E001") +";"      //:Don't translate this text!    //ID for position of element on the folio
     ""+ QObject::tr("F001") +";"      //:Don't translate this text!    //ID for label of element
@@ -105,9 +105,9 @@
     ""+ QObject::tr("N001")+";"       //:Don't translate this text!    //ID for internal number
     ""+ QObject::tr("O001")+";"       //:Don't translate this text!    //ID for location
     ""+ QObject::tr("P001") +"\n";    //:Don't translate this text!    //ID for function
-    data += QObject::tr("N° de folio") +";"
+    data += QObject::tr("Position du folio") +";"
 	""+ QObject::tr("Titre de folio") +";"
-	""+ QObject::tr("Label de folio") +";"
+    ""+ QObject::tr("Numéro de folio") +";"
 	""+ QObject::tr("Désignation qet") +";"
 	""+ QObject::tr("Position") +";"
 	""+ QObject::tr("Label") +";"
@@ -176,11 +176,11 @@
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["formula"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["designation"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["description"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
-	info += autonum::AssignVariables::formulaToLabel(elmt_info["group-function"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+    info += autonum::AssignVariables::formulaToLabel(elmt_info["plant"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["comment"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["manufacturer"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["manufacturer-reference"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
-	info += autonum::AssignVariables::formulaToLabel(elmt_info["provider"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+    info += autonum::AssignVariables::formulaToLabel(elmt_info["supplier"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["quantity"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["unity"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
 	info += autonum::AssignVariables::formulaToLabel(elmt_info["auxiliary1"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";

Modified: trunk/sources/qetapp.cpp
===================================================================
--- trunk/sources/qetapp.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/qetapp.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -294,7 +294,7 @@
 	QStringList info_list;
 	info_list << "formula"
 			  << "label"
-			  << "group-function"
+              << "plant"
 			  << "location"
 			  
 			  << "comment"
@@ -308,7 +308,7 @@
 			  << "manufacturer"
 			  << "manufacturer-reference"
 			  << "machine-manufacturer-reference"
-			  << "provider"
+              << "supplier"
 			  << "quantity"
 			  << "unity";
 	return info_list;
@@ -325,7 +325,7 @@
 {
     if (info == "formula") return tr("Formule du label");
 	else if (info == "label") return tr("Label");
-    else if (info == "group-function") return tr("Installation");
+    else if (info == "plant") return tr("Installation");
 	else if (info == "location") return tr("Localisation");
 	
 	else if (info == "comment") return tr("Commentaire");
@@ -339,7 +339,7 @@
 	else if (info == "manufacturer") return tr("Fabricant");
 	else if (info == "manufacturer-reference") return tr("Numéro de commande");
 	else if (info == "machine-manufacturer-reference") return tr("Numéro interne");
-	else if (info == "provider") return tr("Fournisseur");
+    else if (info == "supplier") return tr("Fournisseur");
 	else if (info == "quantity") return tr("Quantité");
 	else if (info == "unity") return tr("Unité");
 	
@@ -359,13 +359,13 @@
 {
 	if (info == "formula")                             return QString("%{formula}");
 	else if (info == "label")                          return QString("%{label}");
-	else if (info == "group-function")                  return QString("%{group-function}");
+    else if (info == "plant")                          return QString("%{plant}");
 	else if (info == "comment")                        return QString("%{comment}");
 	else if (info == "description")                    return QString("%{description}");
 	else if (info == "designation")                    return QString("%{designation}");
 	else if (info == "manufacturer")                   return QString("%{manufacturer}");
 	else if (info == "manufacturer-reference")         return QString("%{manufacturer-reference}");
-	else if (info == "provider")                       return QString("%{provider}");
+    else if (info == "supplier")                       return QString("%{supplier}");
 	else if (info == "quantity")                       return QString("%{quantity}");
 	else if (info == "unity")                          return QString("%{unity}");
 	else if (info == "auxiliary1")                     return QString("%{auxiliary1}");

Modified: trunk/sources/qetdiagrameditor.cpp
===================================================================
--- trunk/sources/qetdiagrameditor.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/qetdiagrameditor.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -399,7 +399,7 @@
 	});
 	
 		//Lauch the plugin of terminal generator
-	m_project_terminalBloc = new QAction(QET::Icons::TerminalStrip, tr("Lancer le plugin de creation de bornier"), this);
+    m_project_terminalBloc = new QAction(QET::Icons::TerminalStrip, tr("Lancer le plugin de création de borniers"), this);
 	connect(m_project_terminalBloc, &QAction::triggered, this, &QETDiagramEditor::generateTerminalBlock);
 	
 		//MDI view style
@@ -614,7 +614,7 @@
 		this->currentDiagramView()->diagram()->changeZValue(action->data().value<QET::DepthOption>());
 	});
 	
-	m_find = new QAction(tr("Chercher"), this);
+    m_find = new QAction(tr("Chercher/remplacer"), this);
 	m_find->setShortcut(QKeySequence::Find);
 	connect(m_find, &QAction::triggered, [this]() {
 		this->m_search_and_replace_widget.setHidden(!m_search_and_replace_widget.isHidden());

Modified: trunk/sources/titleblock/templatecellwidget.cpp
===================================================================
--- trunk/sources/titleblock/templatecellwidget.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/titleblock/templatecellwidget.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -437,11 +437,11 @@
 		"<li>%{date} : date du folio</li>"
 		"<li>%{title} : titre du folio</li>"
 		"<li>%{filename} : nom de fichier du projet</li>"
-		"<li>%{machine} : nom du groupe fonctionnel du projet</li>"
-		"<li>%{locmach} : nom de la localisation dans le groupe fonctionnel du projet</li>"
+        "<li>%{plant} : nom de l'installation (=) dans laquelle se trouve le folio</li>"
+        "<li>%{locmach} : nom de la localisation (+) dans laquelle se trouve le folio</li>"
 		"<li>%{indexrev} : indice de révision du folio</li>"
 		"<li>%{version} : version du logiciel</li>"
-		"<li>%{folio} : indications relatives au folio</li>"
+        "<li>%{folio} : numéro du folio</li>"
 		"<li>%{folio-id} : position du folio dans le projet</li>"
 		"<li>%{folio-total} : nombre total de folios dans le projet</li>"
 		"<li>%{projecttitle} : titre du projet</li>"

Modified: trunk/sources/titleblockproperties.cpp
===================================================================
--- trunk/sources/titleblockproperties.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/titleblockproperties.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -47,7 +47,7 @@
 		ip.author == author &&\
 		ip.date == date &&\
 		ip.filename == filename &&\
-		ip.machine == machine &&\
+        ip.plant == plant &&\
 		ip.locmach == locmach &&\
 		ip.indexrev == indexrev &&\
 		ip.version == version &&\
@@ -77,7 +77,7 @@
 	e.setAttribute("author",   author);
 	e.setAttribute("title",    title);
 	e.setAttribute("filename", filename);
-	e.setAttribute("machine", machine);
+    e.setAttribute("plant", plant);
 	e.setAttribute("locmach", locmach);
 	e.setAttribute("indexrev",indexrev);
 	e.setAttribute("version", version);
@@ -107,10 +107,10 @@
 	if (e.hasAttribute("author"))      author   = e.attribute("author");
 	if (e.hasAttribute("title"))       title    = e.attribute("title");
 	if (e.hasAttribute("filename"))    filename = e.attribute("filename");
-	if (e.hasAttribute("machine"))    machine   = e.attribute("machine");
+    if (e.hasAttribute("plant"))       plant   = e.attribute("plant");
 	if (e.hasAttribute("locmach"))     locmach  = e.attribute("locmach");
-	if (e.hasAttribute("indexrev"))   indexrev  = e.attribute("indexrev");
-	if (e.hasAttribute("version"))    version   = e.attribute("version");
+    if (e.hasAttribute("indexrev"))    indexrev  = e.attribute("indexrev");
+    if (e.hasAttribute("version"))     version   = e.attribute("version");
 	if (e.hasAttribute("folio"))       folio    = e.attribute("folio");
 	if (e.hasAttribute("auto_page_num")) auto_page_num = e.attribute("auto_page_num");
 	if (e.hasAttribute("date"))        setDateFromString(e.attribute("date"));
@@ -140,7 +140,7 @@
 	settings.setValue(prefix + "title",    title);
 	settings.setValue(prefix + "author",   author);
 	settings.setValue(prefix + "filename", filename);
-	settings.setValue(prefix + "machine", machine);
+    settings.setValue(prefix + "plant", plant);
 	settings.setValue(prefix + "locmach", locmach);
 	settings.setValue(prefix + "indexrev", indexrev);
 	settings.setValue(prefix + "version", version);
@@ -162,7 +162,7 @@
 	title    = settings.value(prefix + "title").toString();
 	author   = settings.value(prefix + "author").toString();
 	filename = settings.value(prefix + "filename").toString();
-	machine  = settings.value(prefix + "machine").toString();
+    plant    = settings.value(prefix + "plant").toString();
 	locmach  = settings.value(prefix + "locmach").toString();
 	indexrev = settings.value(prefix + "indexrev").toString();
 	version  = settings.value(prefix + "version").toString();

Modified: trunk/sources/titleblockproperties.h
===================================================================
--- trunk/sources/titleblockproperties.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/titleblockproperties.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -54,7 +54,7 @@
 	QString author;           ///< Author of the diagram/folio (displayed by the default template)
 	QDate date;               ///< Date (displayed by the default template)
 	QString filename;         ///< Filename (displayed by the default template)
-	QString machine;          ///< Machine (displayed by the default template)
+    QString plant;          ///< Plant (displayed by the default template)
 	QString locmach;              ///< Location(displayed by the default template)
 	QString indexrev;         ///< Revision Index (displayed by the default template)
 	QString version;          ///< Version (displayed by the default template)

Modified: trunk/sources/ui/configpage/generalconfigurationpage.ui
===================================================================
--- trunk/sources/ui/configpage/generalconfigurationpage.ui	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/ui/configpage/generalconfigurationpage.ui	2018-12-04 19:07:14 UTC (rev 5629)
@@ -6,8 +6,8 @@
    <rect>
     <x>0</x>
     <y>0</y>
-    <width>998</width>
-    <height>500</height>
+    <width>1958</width>
+    <height>1438</height>
    </rect>
   </property>
   <property name="sizePolicy">
@@ -133,7 +133,7 @@
        <item row="1" column="0">
         <widget class="QCheckBox" name="m_use_folio_label">
          <property name="text">
-          <string>Utiliser les labels de folio à la place de leurs ID</string>
+          <string>Utiliser les numéros de folio à la place de leur position dans le projet</string>
          </property>
         </widget>
        </item>
@@ -140,7 +140,7 @@
        <item row="3" column="0">
         <widget class="QCheckBox" name="m_border_0">
          <property name="text">
-          <string extracomment="Choix de l'increment de depart 1 ou 0">Activer la numérotation à partir de 0 pour la colonne des cartouches au lieu de 1</string>
+          <string extracomment="Choix de l'increment de depart 1 ou 0">Numéroter les colonnes de cartouche à partir de 0 (1 sinon)</string>
          </property>
         </widget>
        </item>
@@ -223,13 +223,13 @@
      </widget>
      <widget class="QWidget" name="tab_5">
       <attribute name="title">
-       <string>Elements</string>
+       <string>Collections</string>
       </attribute>
       <layout class="QVBoxLayout" name="verticalLayout_2">
        <item>
         <widget class="QGroupBox" name="groupBox_5">
          <property name="title">
-          <string>Collections d'éléments</string>
+          <string>Accès aux collections</string>
          </property>
          <property name="alignment">
           <set>Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop</set>
@@ -241,7 +241,7 @@
           <item row="1" column="0">
            <widget class="QLabel" name="label_7">
             <property name="text">
-             <string>Chemin de la collection commune</string>
+             <string>Répertoire de la collection commune</string>
             </property>
            </widget>
           </item>
@@ -262,7 +262,7 @@
           <item row="2" column="0">
            <widget class="QLabel" name="label_8">
             <property name="text">
-             <string>Chemin de la collection utilisateur</string>
+             <string>Répertoire de la collection utilisateur</string>
             </property>
            </widget>
           </item>
@@ -304,7 +304,7 @@
           <item row="3" column="0">
            <widget class="QLabel" name="label_10">
             <property name="text">
-             <string>Chemin des cartouches utilisateur</string>
+             <string>Répertoire des cartouches utilisateur</string>
             </property>
            </widget>
           </item>

Modified: trunk/sources/ui/reportpropertiewidget.ui
===================================================================
--- trunk/sources/ui/reportpropertiewidget.ui	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/ui/reportpropertiewidget.ui	2018-12-04 19:07:14 UTC (rev 5629)
@@ -6,8 +6,8 @@
    <rect>
     <x>0</x>
     <y>0</y>
-    <width>400</width>
-    <height>300</height>
+    <width>783</width>
+    <height>1175</height>
    </rect>
   </property>
   <property name="windowTitle">
@@ -34,10 +34,10 @@
           <property name="text">
            <string>Vous pouvez définir un label personnalisé pour les reports de folio.
 Créer votre propre texte en vous aidant des variables suivantes :
-%f : le numéro de folio 
-%F: le label de folio
-%M:  Machine 
-%LM: Location
+%f : la position du folio dans le projet 
+%F : le numéro de folio
+%M :  l'installation
+%LM : la localisation
 %l : le numéro de ligne
 %c : le numéro de colonne</string>
           </property>

Modified: trunk/sources/ui/titleblockpropertieswidget.cpp
===================================================================
--- trunk/sources/ui/titleblockpropertieswidget.cpp	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/ui/titleblockpropertieswidget.cpp	2018-12-04 19:07:14 UTC (rev 5629)
@@ -96,7 +96,7 @@
 	ui -> m_title_le  -> setText (properties.title);
 	ui -> m_author_le -> setText (properties.author);
 	ui -> m_file_le   -> setText (properties.filename);
-	ui -> m_mach      -> setText (properties.machine);
+    ui -> m_plant      -> setText (properties.plant);
 	ui -> m_loc   -> setText (properties.locmach);
 	ui -> m_indice    -> setText (properties.indexrev);
 	ui -> m_folio_le  -> setText (properties.folio);
@@ -154,7 +154,7 @@
 	prop.title    = ui -> m_title_le  -> text();
 	prop.author   = ui -> m_author_le -> text();
 	prop.filename = ui -> m_file_le   -> text();
-	prop.machine  = ui -> m_mach      -> text();
+    prop.plant  = ui -> m_plant      -> text();
 	prop.locmach  = ui -> m_loc   -> text();
 	prop.indexrev = ui -> m_indice    -> text();
 	prop.folio    = ui -> m_folio_le  -> text();
@@ -195,7 +195,7 @@
 	prop.title    = ui -> m_title_le  -> text();
 	prop.author   = ui -> m_author_le -> text();
 	prop.filename = ui -> m_file_le   -> text();
-	prop.machine  = ui -> m_mach      -> text();
+    prop.plant    = ui -> m_plant      -> text();
 	prop.locmach  = ui -> m_loc       -> text();
 	prop.indexrev = ui -> m_indice    -> text();
 	prop.folio    = "%autonum";
@@ -294,7 +294,7 @@
 	ui -> m_current_date_rb -> setVisible(current_date);
 
 	m_tbt_edit = new QAction(tr("Éditer ce modèle", "menu entry"), this);
-	m_tbt_duplicate = new QAction(tr("Dupliquer et editer ce modèle", "menu entry"), this);
+    m_tbt_duplicate = new QAction(tr("Dupliquer et éditer ce modèle", "menu entry"), this);
 
 	connect(m_tbt_edit, SIGNAL(triggered()), this, SLOT(editCurrentTitleBlockTemplate()));
 	connect(m_tbt_duplicate, SIGNAL(triggered()), this, SLOT(duplicateCurrentTitleBlockTemplate()));

Modified: trunk/sources/ui/titleblockpropertieswidget.ui
===================================================================
--- trunk/sources/ui/titleblockpropertieswidget.ui	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/ui/titleblockpropertieswidget.ui	2018-12-04 19:07:14 UTC (rev 5629)
@@ -6,8 +6,8 @@
    <rect>
     <x>0</x>
     <y>0</y>
-    <width>654</width>
-    <height>611</height>
+    <width>753</width>
+    <height>901</height>
    </rect>
   </property>
   <property name="sizePolicy">
@@ -51,12 +51,19 @@
          </widget>
         </item>
         <item>
-         <widget class="QComboBox" name="m_tbt_cb"/>
+         <widget class="QComboBox" name="m_tbt_cb">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Expanding">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+         </widget>
         </item>
         <item>
          <widget class="QComboBox" name="m_display_at_cb">
           <property name="sizePolicy">
-           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+           <sizepolicy hsizetype="Preferred" vsizetype="Expanding">
             <horstretch>0</horstretch>
             <verstretch>0</verstretch>
            </sizepolicy>
@@ -63,7 +70,7 @@
           </property>
           <property name="minimumSize">
            <size>
-            <width>40</width>
+            <width>0</width>
             <height>0</height>
            </size>
           </property>
@@ -84,7 +91,7 @@
           </property>
           <item>
            <property name="text">
-            <string notr="true"> </string>
+            <string notr="true"/>
            </property>
            <property name="icon">
             <iconset resource="../../qelectrotech.qrc">
@@ -93,7 +100,7 @@
           </item>
           <item>
            <property name="text">
-            <string notr="true"> </string>
+            <string notr="true"/>
            </property>
            <property name="icon">
             <iconset resource="../../qelectrotech.qrc">
@@ -105,7 +112,7 @@
         <item>
          <widget class="QPushButton" name="m_tbt_pb">
           <property name="sizePolicy">
-           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+           <sizepolicy hsizetype="Preferred" vsizetype="Expanding">
             <horstretch>0</horstretch>
             <verstretch>0</verstretch>
            </sizepolicy>
@@ -232,9 +239,9 @@
              </widget>
             </item>
             <item row="6" column="3">
-             <widget class="QLineEdit" name="m_mach">
+             <widget class="QLineEdit" name="m_plant">
               <property name="toolTip">
-               <string>Disponible en tant que %machine pour les modèles de cartouches</string>
+               <string>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Disponible en tant que %plant pour les modèles de cartouches&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</string>
               </property>
              </widget>
             </item>
@@ -433,7 +440,7 @@
   <tabstop>m_date_now_pb</tabstop>
   <tabstop>m_file_le</tabstop>
   <tabstop>m_folio_le</tabstop>
-  <tabstop>m_mach</tabstop>
+  <tabstop>m_plant</tabstop>
   <tabstop>m_loc</tabstop>
   <tabstop>m_indice</tabstop>
   <tabstop>auto_page_cb</tabstop>


Mail converted by MHonArc 2.6.19+ http://listengine.tuxfamily.org/
--- trunk/sources/bordertitleblock.h	2018-12-03 22:13:16 UTC (rev 5628)
+++ trunk/sources/bordertitleblock.h	2018-12-04 19:07:14 UTC (rev 5629)
@@ -97,8 +97,8 @@
 	QString folio() const { return(btb_folio_); }
 	/// @return the value of the title block "Folio" field as displayed
 	QString finalfolio() const { return(btb_final_folio_); }
-	/// @return the value of the title block "Machine" field
-	QString machine() const { return(btb_machine_); }
+    /// @return the value of the title block "Plant" field
+    QString plant() const { return(btb_plant_); }
 	/// @return the value of the title block "Locmach" field
 	QString locmach() const { return(btb_locmach_); }
 	/// @return the value of the revision index block "Folio" field
@@ -155,7 +155,7 @@
 	}
 	void setFolioData(int, int, const QString& = nullptr, const DiagramContext & = DiagramContext());
 	/// @param author the new value of the "File" field
-	void setMachine(const QString &machine) { btb_machine_ = machine; }
+    void setPlant(const QString &plant) { btb_plant_ = plant; }
 	void setLocMach(const QString &locmach) { btb_locmach_ = locmach; }
 	void setIndicerev(const QString &indexrev){ btb_indexrev_ = indexrev; }
 	void setFileName(const QString &filename) { btb_filename_ = filename; }
@@ -237,7 +237,7 @@
 		QDate   btb_date_;
 		QString btb_title_;
 		QString btb_folio_;
-		QString btb_machine_;
+        QString btb_plant_;
 		QString btb_locmach_;
 		QString btb_indexrev_;
 		QString btb_final_folio_;

Modified: trunk/sources/diagramcontext.h
===================================================================